<?php
// The following definitions are just type hints to support auto complete for nicer development.
// The real work is done by the php SoapClient.

abstract class CouponBlockWebservice
{
    /**
     * @param string $sessionId
     * @param string $couponSource
     * @param string $name
     *
     * @return int
     */
    abstract public function create($sessionId, $couponSource, $name);

    /**
     * @param string $sessionId
     * @param string $couponSource
     *
     * @return int[]
     */
    abstract public function getAllIds($sessionId, $couponSource);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return int
     */
    abstract public function getAssignedCodeCount($sessionId, $blockId);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return int[]
     */
    abstract public function getAssignedMailings($sessionId, $blockId);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return int
     */
    abstract public function getCodeCount($sessionId, $blockId);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return string
     */
    abstract public function getCreated($sessionId, $blockId);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return string
     */
    abstract public function getModified($sessionId, $blockId);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return string
     */
    abstract public function getName($sessionId, $blockId);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return int
     */
    abstract public function getUnAssignedCodeCount($sessionId, $blockId);

    /**
     * @param string $sessionId
     * @param int $blockId
     *
     * @return boolean
     */
    abstract public function remove($sessionId, $blockId);

}

abstract class CouponCodeWebservice
{
    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return boolean
     */
    abstract public function add($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string[] $codes
     *
     * @return boolean[]
     */
    abstract public function addAll($sessionId, $blockId, $codes);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param int $mailingId
     * @param int $startEntry
     * @param int $numberOfEntries
     *
     * @return string[]
     */
    abstract public function getAllAssigned($sessionId, $blockId, $mailingId, $startEntry, $numberOfEntries);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param int $startEntry
     * @param int $numberOfEntries
     *
     * @return string[]
     */
    abstract public function getAllUnAssigned($sessionId, $blockId, $startEntry, $numberOfEntries);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return int
     */
    abstract public function getAssignedMailing($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return string
     */
    abstract public function getAssignedRecipientId($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param int $mailingId
     * @param string $recipientId
     *
     * @return string[]
     */
    abstract public function getByMailingAndRecipientId($sessionId, $blockId, $mailingId, $recipientId);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return string
     */
    abstract public function getCreated($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return string
     */
    abstract public function getModified($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return boolean
     */
    abstract public function isAssigned($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return boolean
     */
    abstract public function isUsed($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     */
    abstract public function markAsUsed($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string $code
     *
     * @return boolean
     */
    abstract public function remove($sessionId, $blockId, $code);

    /**
     * @param string $sessionId
     * @param int $blockId
     * @param string[] $codes
     *
     * @return boolean[]
     */
    abstract public function removeAll($sessionId, $blockId, $codes);

}

class BroadmailAddonsApi
{
    /**
     * @return CouponBlockWebservice
     */
    public static function CouponBlockWebservice()
    {
        return new SoapClient("https://api.broadmail.de/soap11/addons/RpcCouponBlock?wsdl");
    }

    /**
     * @return CouponCodeWebservice
     */
    public static function CouponCodeWebservice()
    {
        return new SoapClient("https://api.broadmail.de/soap11/addons/RpcCouponCode?wsdl");
    }

}
